@@ -61,56 +61,60 @@
 #include "rdkafkacpp.h"
 
 static volatile sig_atomic_t run = 1;
-static bool exit_eof = false;
-static int verbosity = 1;
+static bool exit_eof             = false;
+static int verbosity             = 1;
 static std::string value_prefix;
 
 class Assignment {
-
  public:
-  static std::string name (const std::string &t, int partition) {
+  static std::string name(const std::string &t, int partition) {
     std::stringstream stm;
     stm << t << "." << partition;
     return stm.str();
   }
 
-  Assignment(): topic(""), partition(-1), consumedMessages(0),
-                minOffset(-1), maxOffset(0) {
+  Assignment() :
+      topic(""),
+      partition(-1),
+      consumedMessages(0),
+      minOffset(-1),
+      maxOffset(0) {
     printf("Created assignment\n");
   }
   Assignment(const Assignment &a) {
-    topic = a.topic;
-    partition = a.partition;
+    topic            = a.topic;
+    partition        = a.partition;
     consumedMessages = a.consumedMessages;
-    minOffset = a.minOffset;
-    maxOffset = a.maxOffset;
+    minOffset        = a.minOffset;
+    maxOffset        = a.maxOffset;
   }
 
   Assignment &operator=(const Assignment &a) {
-    this->topic = a.topic;
-    this->partition = a.partition;
+    this->topic            = a.topic;
+    this->partition        = a.partition;
     this->consumedMessages = a.consumedMessages;
-    this->minOffset = a.minOffset;
-    this->maxOffset = a.maxOffset;
+    this->minOffset        = a.minOffset;
+    this->maxOffset        = a.maxOffset;
     return *this;
   }
 
   int operator==(const Assignment &a) const {
-    return !(this->topic == a.topic &&
-             this->partition == a.partition);
+    return !(this->topic == a.topic && this->partition == a.partition);
   }
 
   int operator<(const Assignment &a) const {
-    if (this->topic < a.topic) return 1;
-    if (this->topic >= a.topic) return 0;
+    if (this->topic < a.topic)
+      return 1;
+    if (this->topic >= a.topic)
+      return 0;
     return (this->partition < a.partition);
   }
 
-  void setup (std::string t, int32_t p) {
+  void setup(std::string t, int32_t p) {
     assert(!t.empty());
     assert(topic.empty() || topic == t);
     assert(partition == -1 || partition == p);
-    topic = t;
+    topic     = t;
     partition = p;
   }
 
@@ -123,7 +127,6 @@ class Assignment {
 
 
 
-
 static struct {
   int maxMessages;
 
@@ -141,14 +144,13 @@ static struct {
     std::map<std::string, Assignment> assignments;
   } consumer;
 } state = {
-  /* .maxMessages = */ -1
-};
+    /* .maxMessages = */ -1};
 
 
 static RdKafka::KafkaConsumer *consumer;
 
 
-static std::string now () {
+static std::string now() {
   struct timeval tv;
   gettimeofday(&tv, NULL);
   time_t t = tv.tv_sec;
@@ -157,7 +159,7 @@ static std::string now () {
 
   localtime_r(&t, &tm);
   strftime(buf, sizeof(buf), "%H:%M:%S", &tm);
-  snprintf(buf+strlen(buf), sizeof(buf)-strlen(buf), ".%03d",
+  snprintf(buf + strlen(buf), sizeof(buf) - strlen(buf), ".%03d",
            (int)(tv.tv_usec / 1000));
 
   return buf;
@@ -166,18 +168,19 @@ static std::string now () {
 
 static time_t watchdog_last_kick;
 static const int watchdog_timeout = 20; /* Must be > socket.timeout.ms */
-static void sigwatchdog (int sig) {
+static void sigwatchdog(int sig) {
   time_t t = time(NULL);
   if (watchdog_last_kick + watchdog_timeout <= t) {
-    std::cerr << now() << ": WATCHDOG TIMEOUT (" <<
-        (int)(t - watchdog_last_kick) << "s): TERMINATING" << std::endl;
+    std::cerr << now() << ": WATCHDOG TIMEOUT ("
+              << (int)(t - watchdog_last_kick) << "s): TERMINATING"
+              << std::endl;
     int *i = NULL;
-    *i = 100;
+    *i     = 100;
     abort();
   }
 }
 
-static void watchdog_kick () {
+static void watchdog_kick() {
   watchdog_last_kick = time(NULL);
 
   /* Safe guard against hangs-on-exit */
@@ -186,13 +189,11 @@ static void watchdog_kick () {
 
 
 
-
-
-static void errorString (const std::string &name,
-                         const std::string &errmsg,
-                         const std::string &topic,
-                         const std::string *key,
-                         const std::string &value) {
+static void errorString(const std::string &name,
+                        const std::string &errmsg,
+                        const std::string &topic,
+                        const std::string *key,
+                        const std::string &value) {
   std::cout << "{ "
             << "\"name\": \"" << name << "\", "
             << "\"_time\": \"" << now() << "\", "
@@ -204,12 +205,12 @@ static void errorString (const std::string &name,
 }
 
 
-static void successString (const std::string &name,
-                           const std::string &topic,
-                           int partition,
-                           int64_t offset,
-                           const std::string *key,
-                           const std::string &value) {
+static void successString(const std::string &name,
+                          const std::string &topic,
+                          int partition,
+                          int64_t offset,
+                          const std::string *key,
+                          const std::string &value) {
   std::cout << "{ "
             << "\"name\": \"" << name << "\", "
             << "\"_time\": \"" << now() << "\", "
@@ -223,29 +224,27 @@ static void successString (const std::string &name,
 
 
 #if FIXME
-static void offsetStatus (bool success,
-                          const std::string &topic,
-                          int partition,
-                          int64_t offset,
-                          const std::string &errstr) {
+static void offsetStatus(bool success,
+                         const std::string &topic,
+                         int partition,
+                         int64_t offset,
+                         const std::string &errstr) {
   std::cout << "{ "
-      "\"name\": \"offsets_committed\", " <<
-      "\"success\": " << success << ", " <<
-      "\"offsets\": [ " <<
-      " { " <<
-      " \"topic\": \"" << topic << "\", " <<
-      " \"partition\": " << partition << ", " <<
-      " \"offset\": " << (int)offset << ", " <<
-      " \"error\": \"" << errstr << "\" " <<
-      " } " <<
-      "] }" << std::endl;
-
+               "\"name\": \"offsets_committed\", "
+            << "\"success\": " << success << ", "
+            << "\"offsets\": [ "
+            << " { "
+            << " \"topic\": \"" << topic << "\", "
+            << " \"partition\": " << partition << ", "
+            << " \"offset\": " << (int)offset << ", "
+            << " \"error\": \"" << errstr << "\" "
+            << " } "
+            << "] }" << std::endl;
 }
 #endif
 
 
-static void sigterm (int sig) {
-
+static void sigterm(int sig) {
   std::cerr << now() << ": Terminating because of signal " << sig << std::endl;
 
   if (!run) {
@@ -258,21 +257,17 @@ static void sigterm (int sig) {
 
 class ExampleDeliveryReportCb : public RdKafka::DeliveryReportCb {
  public:
-  void dr_cb (RdKafka::Message &message) {
+  void dr_cb(RdKafka::Message &message) {
     if (message.err()) {
       state.producer.numErr++;
-      errorString("producer_send_error", message.errstr(),
-                  message.topic_name(),
+      errorString("producer_send_error", message.errstr(), message.topic_name(),
                   message.key(),
-                  std::string(static_cast<const char*>(message.payload()),
+                  std::string(static_cast<const char *>(message.payload()),
                               message.len()));
     } else {
-      successString("producer_send_success",
-                    message.topic_name(),
-                    (int)message.partition(),
-                    message.offset(),
-                    message.key(),
-                    std::string(static_cast<const char*>(message.payload()),
+      successString("producer_send_success", message.topic_name(),
+                    (int)message.partition(), message.offset(), message.key(),
+                    std::string(static_cast<const char *>(message.payload()),
                                 message.len()));
       state.producer.numAcked++;
     }
@@ -282,28 +277,27 @@ class ExampleDeliveryReportCb : public RdKafka::DeliveryReportCb {
 
 class ExampleEventCb : public RdKafka::EventCb {
  public:
-  void event_cb (RdKafka::Event &event) {
-    switch (event.type())
-    {
-      case RdKafka::Event::EVENT_ERROR:
-        std::cerr << now() << ": ERROR (" << RdKafka::err2str(event.err()) << "): " <<
-            event.str() << std::endl;
-        break;
+  void event_cb(RdKafka::Event &event) {
+    switch (event.type()) {
+    case RdKafka::Event::EVENT_ERROR:
+      std::cerr << now() << ": ERROR (" << RdKafka::err2str(event.err())
+                << "): " << event.str() << std::endl;
+      break;
 
-      case RdKafka::Event::EVENT_STATS:
-        std::cerr << now() << ": \"STATS\": " << event.str() << std::endl;
-        break;
+    case RdKafka::Event::EVENT_STATS:
+      std::cerr << now() << ": \"STATS\": " << event.str() << std::endl;
+      break;
 
-      case RdKafka::Event::EVENT_LOG:
-        std::cerr << now() << ": LOG-" << event.severity() << "-"
-                  << event.fac() << ": " << event.str() << std::endl;
-        break;
+    case RdKafka::Event::EVENT_LOG:
+      std::cerr << now() << ": LOG-" << event.severity() << "-" << event.fac()
+                << ": " << event.str() << std::endl;
+      break;
 
-      default:
-        std::cerr << now() << ": EVENT " << event.type() <<
-            " (" << RdKafka::err2str(event.err()) << "): " <<
-            event.str() << std::endl;
-        break;
+    default:
+      std::cerr << now() << ": EVENT " << event.type() << " ("
+                << RdKafka::err2str(event.err()) << "): " << event.str()
+                << std::endl;
+      break;
     }
   }
 };
@@ -313,15 +307,17 @@ class ExampleEventCb : public RdKafka::EventCb {
  * in the produce() call. */
 class MyHashPartitionerCb : public RdKafka::PartitionerCb {
  public:
-  int32_t partitioner_cb (const RdKafka::Topic *topic, const std::string *key,
-                          int32_t partition_cnt, void *msg_opaque) {
+  int32_t partitioner_cb(const RdKafka::Topic *topic,
+                         const std::string *key,
+                         int32_t partition_cnt,
+                         void *msg_opaque) {
     return djb_hash(key->c_str(), key->size()) % partition_cnt;
   }
- private:
 
-  static inline unsigned int djb_hash (const char *str, size_t len) {
+ private:
+  static inline unsigned int djb_hash(const char *str, size_t len) {
     unsigned int hash = 5381;
-    for (size_t i = 0 ; i < len ; i++)
+    for (size_t i = 0; i < len; i++)
       hash = ((hash << 5) + hash) + str[i];
     return hash;
   }
@@ -329,35 +325,35 @@ class MyHashPartitionerCb : public RdKafka::PartitionerCb {
 
 
 
-
-
 /**
  * Print number of records consumed, every 100 messages or on timeout.
  */
-static void report_records_consumed (int immediate) {
-  std::map<std::string,Assignment> *assignments = &state.consumer.assignments;
+static void report_records_consumed(int immediate) {
+  std::map<std::string, Assignment> *assignments = &state.consumer.assignments;
 
   if (state.consumer.consumedMessages <=
       state.consumer.consumedMessagesLastReported + (immediate ? 0 : 999))
     return;
 
   std::cout << "{ "
-      "\"name\": \"records_consumed\", " <<
-      "\"_totcount\": " << state.consumer.consumedMessages << ", " <<
-      "\"count\": " << (state.consumer.consumedMessages -
-                        state.consumer.consumedMessagesLastReported) << ", " <<
-      "\"partitions\": [ ";
+               "\"name\": \"records_consumed\", "
+            << "\"_totcount\": " << state.consumer.consumedMessages << ", "
+            << "\"count\": "
+            << (state.consumer.consumedMessages -
+                state.consumer.consumedMessagesLastReported)
+            << ", "
+            << "\"partitions\": [ ";
 
-  for (std::map<std::string,Assignment>::iterator ii = assignments->begin() ;
-       ii != assignments->end() ; ii++) {
+  for (std::map<std::string, Assignment>::iterator ii = assignments->begin();
+       ii != assignments->end(); ii++) {
     Assignment *a = &(*ii).second;
     assert(!a->topic.empty());
-    std::cout << (ii == assignments->begin() ? "": ", ") << " { " <<
-        " \"topic\": \"" << a->topic << "\", " <<
-        " \"partition\": " << a->partition << ", " <<
-        " \"minOffset\": " << a->minOffset << ", " <<
-        " \"maxOffset\": " << a->maxOffset << " " <<
-        " } ";
+    std::cout << (ii == assignments->begin() ? "" : ", ") << " { "
+              << " \"topic\": \"" << a->topic << "\", "
+              << " \"partition\": " << a->partition << ", "
+              << " \"minOffset\": " << a->minOffset << ", "
+              << " \"maxOffset\": " << a->maxOffset << " "
+              << " } ";
     a->minOffset = -1;
   }
 
@@ -369,36 +365,39 @@ static void report_records_consumed (int immediate) {
 
 class ExampleOffsetCommitCb : public RdKafka::OffsetCommitCb {
  public:
-  void offset_commit_cb (RdKafka::ErrorCode err,
-                         std::vector<RdKafka::TopicPartition*> &offsets) {
-    std::cerr << now() << ": Propagate offset for " << offsets.size() << " partitions, error: " << RdKafka::err2str(err) << std::endl;
+  void offset_commit_cb(RdKafka::ErrorCode err,
+                        std::vector<RdKafka::TopicPartition *> &offsets) {
+    std::cerr << now() << ": Propagate offset for " << offsets.size()
+              << " partitions, error: " << RdKafka::err2str(err) << std::endl;
 
     /* No offsets to commit, dont report anything. */
     if (err == RdKafka::ERR__NO_OFFSET)
       return;
 
-    /* Send up-to-date records_consumed report to make sure consumed > committed */
+    /* Send up-to-date records_consumed report to make sure consumed > committed
+     */
     report_records_consumed(1);
 
-    std::cout << "{ " <<
-        "\"name\": \"offsets_committed\", " <<
-        "\"success\": " << (err ? "false" : "true") << ", " <<
-        "\"error\": \"" << (err ? RdKafka::err2str(err) : "") << "\", " <<
-        "\"_autocommit\": " << (state.consumer.useAutoCommit ? "true":"false") << ", " <<
-        "\"offsets\": [ ";
+    std::cout << "{ "
+              << "\"name\": \"offsets_committed\", "
+              << "\"success\": " << (err ? "false" : "true") << ", "
+              << "\"error\": \"" << (err ? RdKafka::err2str(err) : "") << "\", "
+              << "\"_autocommit\": "
+              << (state.consumer.useAutoCommit ? "true" : "false") << ", "
+              << "\"offsets\": [ ";
     assert(offsets.size() > 0);
-    for (unsigned int i = 0 ; i < offsets.size() ; i++) {
-      std::cout << (i == 0 ? "" : ", ") << "{ " <<
-          " \"topic\": \"" << offsets[i]->topic() << "\", " <<
-          " \"partition\": " << offsets[i]->partition() << ", " <<
-          " \"offset\": " << (int)offsets[i]->offset() << ", " <<
-          " \"error\": \"" <<
-          (offsets[i]->err() ? RdKafka::err2str(offsets[i]->err()) : "") <<
-          "\" " <<
-          " }";
+    for (unsigned int i = 0; i < offsets.size(); i++) {
+      std::cout << (i == 0 ? "" : ", ") << "{ "
+                << " \"topic\": \"" << offsets[i]->topic() << "\", "
+                << " \"partition\": " << offsets[i]->partition() << ", "
+                << " \"offset\": " << (int)offsets[i]->offset() << ", "
+                << " \"error\": \""
+                << (offsets[i]->err() ? RdKafka::err2str(offsets[i]->err())
+                                      : "")
+                << "\" "
+                << " }";
     }
     std::cout << " ] }" << std::endl;
-
   }
 };
 
@@ -408,12 +407,10 @@ static ExampleOffsetCommitCb ex_offset_commit_cb;
 /**
  * Commit every 1000 messages or whenever there is a consume timeout.
  */
-static void do_commit (RdKafka::KafkaConsumer *consumer,
-                      int immediate) {
-  if (!immediate &&
-      (state.consumer.useAutoCommit ||
-       state.consumer.consumedMessagesAtLastCommit + 1000 >
-       state.consumer.consumedMessages))
+static void do_commit(RdKafka::KafkaConsumer *consumer, int immediate) {
+  if (!immediate && (state.consumer.useAutoCommit ||
+                     state.consumer.consumedMessagesAtLastCommit + 1000 >
+                         state.consumer.consumedMessages))
     return;
 
   /* Make sure we report consumption before commit,
@@ -422,106 +419,102 @@ static void do_commit (RdKafka::KafkaConsumer *consumer,
       state.consumer.consumedMessages)
     report_records_consumed(1);
 
-  std::cerr << now() << ": committing " <<
-    (state.consumer.consumedMessages -
-     state.consumer.consumedMessagesAtLastCommit) << " messages" << std::endl;
+  std::cerr << now() << ": committing "
+            << (state.consumer.consumedMessages -
+                state.consumer.consumedMessagesAtLastCommit)
+            << " messages" << std::endl;
 
   RdKafka::ErrorCode err;
   err = consumer->commitSync(&ex_offset_commit_cb);
 
-  std::cerr << now() << ": " <<
-    "sync commit returned " << RdKafka::err2str(err) << std::endl;
+  std::cerr << now() << ": "
+            << "sync commit returned " << RdKafka::err2str(err) << std::endl;
 
-  state.consumer.consumedMessagesAtLastCommit =
-    state.consumer.consumedMessages;
+  state.consumer.consumedMessagesAtLastCommit = state.consumer.consumedMessages;
 }
 
 
 void msg_consume(RdKafka::KafkaConsumer *consumer,
-                 RdKafka::Message* msg, void* opaque) {
+                 RdKafka::Message *msg,
+                 void *opaque) {
   switch (msg->err()) {
-    case RdKafka::ERR__TIMED_OUT:
-      /* Try reporting consumed messages */
-      report_records_consumed(1);
-      /* Commit one every consume() timeout instead of on every message.
-       * Also commit on every 1000 messages, whichever comes first. */
-      do_commit(consumer, 1);
-      break;
+  case RdKafka::ERR__TIMED_OUT:
+    /* Try reporting consumed messages */
+    report_records_consumed(1);
+    /* Commit one every consume() timeout instead of on every message.
+     * Also commit on every 1000 messages, whichever comes first. */
+    do_commit(consumer, 1);
+    break;
 
 
-    case RdKafka::ERR_NO_ERROR:
-      {
-        /* Real message */
-        if (verbosity > 2)
-          std::cerr << now() << ": Read msg from " << msg->topic_name() <<
-              " [" << (int)msg->partition() << "]  at offset " <<
-              msg->offset() << std::endl;
+  case RdKafka::ERR_NO_ERROR: {
+    /* Real message */
+    if (verbosity > 2)
+      std::cerr << now() << ": Read msg from " << msg->topic_name() << " ["
+                << (int)msg->partition() << "]  at offset " << msg->offset()
+                << std::endl;
 
-        if (state.maxMessages >= 0 &&
-            state.consumer.consumedMessages >= state.maxMessages)
-          return;
+    if (state.maxMessages >= 0 &&
+        state.consumer.consumedMessages >= state.maxMessages)
+      return;
 
 
-        Assignment *a =
-            &state.consumer.assignments[Assignment::name(msg->topic_name(),
-                                                         msg->partition())];
-        a->setup(msg->topic_name(), msg->partition());
+    Assignment *a = &state.consumer.assignments[Assignment::name(
+        msg->topic_name(), msg->partition())];
+    a->setup(msg->topic_name(), msg->partition());
 
-        a->consumedMessages++;
-        if (a->minOffset == -1)
-          a->minOffset = msg->offset();
-        if (a->maxOffset < msg->offset())
-          a->maxOffset = msg->offset();
+    a->consumedMessages++;
+    if (a->minOffset == -1)
+      a->minOffset = msg->offset();
+    if (a->maxOffset < msg->offset())
+      a->maxOffset = msg->offset();
 
-        if (msg->key()) {
-          if (verbosity >= 3)
-            std::cerr << now() << ": Key: " << *msg->key() << std::endl;
-        }
+    if (msg->key()) {
+      if (verbosity >= 3)
+        std::cerr << now() << ": Key: " << *msg->key() << std::endl;
+    }
 
-        if (verbosity >= 3)
-          fprintf(stderr, "%.*s\n",
-                  static_cast<int>(msg->len()),
-                  static_cast<const char *>(msg->payload()));
+    if (verbosity >= 3)
+      fprintf(stderr, "%.*s\n", static_cast<int>(msg->len()),
+              static_cast<const char *>(msg->payload()));
 
-        state.consumer.consumedMessages++;
+    state.consumer.consumedMessages++;
 
-        report_records_consumed(0);
+    report_records_consumed(0);
 
-        do_commit(consumer, 0);
-      }
-      break;
+    do_commit(consumer, 0);
+  } break;
 
-    case RdKafka::ERR__PARTITION_EOF:
-      /* Last message */
-      if (exit_eof) {
-        std::cerr << now() << ": Terminate: exit on EOF" << std::endl;
-        run = 0;
-      }
-      break;
-
-    case RdKafka::ERR__UNKNOWN_TOPIC:
-    case RdKafka::ERR__UNKNOWN_PARTITION:
-      std::cerr << now() << ": Consume failed: " << msg->errstr() << std::endl;
+  case RdKafka::ERR__PARTITION_EOF:
+    /* Last message */
+    if (exit_eof) {
+      std::cerr << now() << ": Terminate: exit on EOF" << std::endl;
       run = 0;
-      break;
+    }
+    break;
 
-    case RdKafka::ERR_GROUP_COORDINATOR_NOT_AVAILABLE:
-      std::cerr << now() << ": Warning: " << msg->errstr() << std::endl;
-      break;
+  case RdKafka::ERR__UNKNOWN_TOPIC:
+  case RdKafka::ERR__UNKNOWN_PARTITION:
+    std::cerr << now() << ": Consume failed: " << msg->errstr() << std::endl;
+    run = 0;
+    break;
 
-    default:
-      /* Errors */
-      std::cerr << now() << ": Consume failed: " << msg->errstr() << std::endl;
-      run = 0;
+  case RdKafka::ERR_GROUP_COORDINATOR_NOT_AVAILABLE:
+    std::cerr << now() << ": Warning: " << msg->errstr() << std::endl;
+    break;
+
+  default:
+    /* Errors */
+    std::cerr << now() << ": Consume failed: " << msg->errstr() << std::endl;
+    run = 0;
   }
 }
 
 
 
-
 class ExampleConsumeCb : public RdKafka::ConsumeCb {
  public:
-  void consume_cb (RdKafka::Message &msg, void *opaque) {
+  void consume_cb(RdKafka::Message &msg, void *opaque) {
     msg_consume(consumer_, &msg, opaque);
   }
   RdKafka::KafkaConsumer *consumer_;
@@ -529,22 +522,22 @@ class ExampleConsumeCb : public RdKafka::ConsumeCb {
 
 class ExampleRebalanceCb : public RdKafka::RebalanceCb {
  private:
-  static std::string part_list_json (const std::vector<RdKafka::TopicPartition*> &partitions) {
+  static std::string part_list_json(
+      const std::vector<RdKafka::TopicPartition *> &partitions) {
     std::ostringstream out;
-    for (unsigned int i = 0 ; i < partitions.size() ; i++)
-      out << (i==0?"":", ") << "{ " <<
-          " \"topic\": \"" << partitions[i]->topic() << "\", " <<
-          " \"partition\": " << partitions[i]->partition() <<
-          " }";
+    for (unsigned int i = 0; i < partitions.size(); i++)
+      out << (i == 0 ? "" : ", ") << "{ "
+          << " \"topic\": \"" << partitions[i]->topic() << "\", "
+          << " \"partition\": " << partitions[i]->partition() << " }";
     return out.str();
   }
- public:
-  void rebalance_cb (RdKafka::KafkaConsumer *consumer,
-                     RdKafka::ErrorCode err,
-                     std::vector<RdKafka::TopicPartition*> &partitions) {
 
-    std::cerr << now() << ": rebalance_cb " << RdKafka::err2str(err) <<
-        " for " << partitions.size() << " partitions" << std::endl;
+ public:
+  void rebalance_cb(RdKafka::KafkaConsumer *consumer,
+                    RdKafka::ErrorCode err,
+                    std::vector<RdKafka::TopicPartition *> &partitions) {
+    std::cerr << now() << ": rebalance_cb " << RdKafka::err2str(err) << " for "
+              << partitions.size() << " partitions" << std::endl;
     /* Send message report prior to rebalancing event to make sure they
      * are accounted for on the "right side" of the rebalance. */
     report_records_consumed(1);
@@ -556,12 +549,13 @@ class ExampleRebalanceCb : public RdKafka::RebalanceCb {
       consumer->unassign();
     }
 
-    std::cout <<
-      "{ " <<
-      "\"name\": \"partitions_" << (err == RdKafka::ERR__ASSIGN_PARTITIONS ?
-                                    "assigned" : "revoked") << "\", " <<
-      "\"partitions\": [ " << part_list_json(partitions) << "] }" << std::endl;
-
+    std::cout << "{ "
+              << "\"name\": \"partitions_"
+              << (err == RdKafka::ERR__ASSIGN_PARTITIONS ? "assigned"
+                                                         : "revoked")
+              << "\", "
+              << "\"partitions\": [ " << part_list_json(partitions) << "] }"
+              << std::endl;
   }
 };
 
@@ -570,11 +564,12 @@ class ExampleRebalanceCb : public RdKafka::RebalanceCb {
 /**
  * @brief Read (Java client) configuration file
  */
-static void read_conf_file (RdKafka::Conf *conf, const std::string &conf_file) {
+static void read_conf_file(RdKafka::Conf *conf, const std::string &conf_file) {
   std::ifstream inf(conf_file.c_str());
 
   if (!inf) {
-    std::cerr << now() << ": " << conf_file << ": could not open file" << std::endl;
+    std::cerr << now() << ": " << conf_file << ": could not open file"
+              << std::endl;
     exit(1);
   }
 
@@ -593,18 +588,23 @@ static void read_conf_file (RdKafka::Conf *conf, const std::string &conf_file) {
     // Match on key=value..
     size_t d = line.find("=");
     if (d == 0 || d == std::string::npos) {
-      std::cerr << now() << ": " << conf_file << ":" << linenr << ": " << line << ": ignoring invalid line (expect key=value): " << ::std::endl;
+      std::cerr << now() << ": " << conf_file << ":" << linenr << ": " << line
+                << ": ignoring invalid line (expect key=value): "
+                << ::std::endl;
       continue;
     }
 
     std::string key = line.substr(0, d);
-    std::string val = line.substr(d+1);
+    std::string val = line.substr(d + 1);
 
     std::string errstr;
     if (conf->set(key, val, errstr)) {
-      std::cerr << now() << ": " << conf_file << ":" << linenr << ": " << key << "=" << val << ": " << errstr << ": ignoring error" << std::endl;
+      std::cerr << now() << ": " << conf_file << ":" << linenr << ": " << key
+                << "=" << val << ": " << errstr << ": ignoring error"
+                << std::endl;
     } else {
-      std::cerr << now() << ": " << conf_file << ":" << linenr << ": " << key << "=" << val << ": applied to configuration" << std::endl;
+      std::cerr << now() << ": " << conf_file << ":" << linenr << ": " << key
+                << "=" << val << ": applied to configuration" << std::endl;
     }
   }
 
@@ -613,19 +613,18 @@ static void read_conf_file (RdKafka::Conf *conf, const std::string &conf_file) {
 
 
 
-
-int main (int argc, char **argv) {
+int main(int argc, char **argv) {
   std::string brokers = "localhost";
   std::string errstr;
   std::vector<std::string> topics;
-  std::string mode = "P";
-  int throughput = 0;
+  std::string mode  = "P";
+  int throughput    = 0;
   int32_t partition = RdKafka::Topic::PARTITION_UA;
   MyHashPartitionerCb hash_partitioner;
   int64_t create_time = -1;
 
-  std::cerr << now() << ": librdkafka version " << RdKafka::version_str() <<
-    " (" << RdKafka::version() << ")" << std::endl;
+  std::cerr << now() << ": librdkafka version " << RdKafka::version_str()
+            << " (" << RdKafka::version() << ")" << std::endl;
 
   /*
    * Create configuration objects
@@ -646,7 +645,7 @@ int main (int argc, char **argv) {
 
   {
     char hostname[128];
-    gethostname(hostname, sizeof(hostname)-1);
+    gethostname(hostname, sizeof(hostname) - 1);
     conf->set("client.id", std::string("rdkafka@") + hostname, errstr);
   }
 
@@ -664,15 +663,15 @@ int main (int argc, char **argv) {
 
   conf->set("enable.partition.eof", "true", errstr);
 
-  for (int i = 1 ; i < argc ; i++) {
+  for (int i = 1; i < argc; i++) {
     const char *name = argv[i];
-    const char *val = i+1 < argc ? argv[i+1] : NULL;
+    const char *val  = i + 1 < argc ? argv[i + 1] : NULL;
 
     if (val && !strncmp(val, "-", 1))
       val = NULL;
 
-    std::cout << now() << ": argument: " << name << " " <<
-        (val?val:"") << std::endl;
+    std::cout << now() << ": argument: " << name << " " << (val ? val : "")
+              << std::endl;
 
     if (val) {
       if (!strcmp(name, "--topic"))
@@ -712,22 +711,22 @@ int main (int argc, char **argv) {
 
         std::transform(s.begin(), s.end(), s.begin(), tolower);
 
-        std::cerr << now() << ": converted " << name << " "
-                  << val << " to " << s << std::endl;
+        std::cerr << now() << ": converted " << name << " " << val << " to "
+                  << s << std::endl;
 
-        if  (conf->set("partition.assignment.strategy", s.c_str(), errstr)) {
+        if (conf->set("partition.assignment.strategy", s.c_str(), errstr)) {
           std::cerr << now() << ": " << errstr << std::endl;
           exit(1);
         }
       } else if (!strcmp(name, "--value-prefix")) {
         value_prefix = std::string(val) + ".";
       } else if (!strcmp(name, "--acks")) {
-       if (conf->set("acks", val, errstr)) {
-         std::cerr << now() << ": " << errstr << std::endl;
-         exit(1);
-       }
+        if (conf->set("acks", val, errstr)) {
+          std::cerr << now() << ": " << errstr << std::endl;
+          exit(1);
+        }
       } else if (!strcmp(name, "--message-create-time")) {
-       create_time = (int64_t)atoi(val);
+        create_time = (int64_t)atoi(val);
       } else if (!strcmp(name, "--debug")) {
         conf->set("debug", val, errstr);
       } else if (!strcmp(name, "-X")) {
@@ -764,7 +763,8 @@ int main (int argc, char **argv) {
       else if (!strcmp(name, "-q"))
         verbosity--;
       else {
-        std::cerr << now() << ": Unknown option or missing argument to " << name << std::endl;
+        std::cerr << now() << ": Unknown option or missing argument to " << name
+                  << std::endl;
         exit(1);
       }
     }
@@ -786,7 +786,7 @@ int main (int argc, char **argv) {
 
   signal(SIGINT, sigterm);
   signal(SIGTERM, sigterm);
-  signal(SIGALRM,  sigwatchdog);
+  signal(SIGALRM, sigwatchdog);
 
 
   if (mode == "P") {
@@ -804,28 +804,30 @@ int main (int argc, char **argv) {
      */
     RdKafka::Producer *producer = RdKafka::Producer::create(conf, errstr);
     if (!producer) {
-      std::cerr << now() << ": Failed to create producer: " << errstr << std::endl;
+      std::cerr << now() << ": Failed to create producer: " << errstr
+                << std::endl;
       exit(1);
     }
 
-    std::cerr << now() << ": % Created producer " << producer->name() << std::endl;
+    std::cerr << now() << ": % Created producer " << producer->name()
+              << std::endl;
 
     /*
      * Create topic handle.
      */
-    RdKafka::Topic *topic = RdKafka::Topic::create(producer, topics[0],
-                                                   NULL, errstr);
+    RdKafka::Topic *topic =
+        RdKafka::Topic::create(producer, topics[0], NULL, errstr);
     if (!topic) {
       std::cerr << now() << ": Failed to create topic: " << errstr << std::endl;
       exit(1);
     }
 
-    static const int delay_us = throughput ? 1000000/throughput : 10;
+    static const int delay_us = throughput ? 1000000 / throughput : 10;
 
     if (state.maxMessages == -1)
       state.maxMessages = 1000000; /* Avoid infinite produce */
 
-    for (int i = 0 ; run && i < state.maxMessages ; i++) {
+    for (int i = 0; run && i < state.maxMessages; i++) {
       /*
        * Produce message
        */
@@ -833,27 +835,26 @@ int main (int argc, char **argv) {
       msg << value_prefix << i;
       while (true) {
         RdKafka::ErrorCode resp;
-       if (create_time == -1) {
-         resp = producer->produce(topic, partition,
-                                  RdKafka::Producer::RK_MSG_COPY /* Copy payload */,
-                                  const_cast<char *>(msg.str().c_str()),
-                                  msg.str().size(), NULL, NULL);
-       } else {
-         resp = producer->produce(topics[0], partition,
-                                  RdKafka::Producer::RK_MSG_COPY /* Copy payload */,
-                                  const_cast<char *>(msg.str().c_str()),
-                                  msg.str().size(),
-                                  NULL, 0,
-                                  create_time,
-                                  NULL);
-       }
+        if (create_time == -1) {
+          resp = producer->produce(
+              topic, partition,
+              RdKafka::Producer::RK_MSG_COPY /* Copy payload */,
+              const_cast<char *>(msg.str().c_str()), msg.str().size(), NULL,
+              NULL);
+        } else {
+          resp = producer->produce(
+              topics[0], partition,
+              RdKafka::Producer::RK_MSG_COPY /* Copy payload */,
+              const_cast<char *>(msg.str().c_str()), msg.str().size(), NULL, 0,
+              create_time, NULL);
+        }
 
         if (resp == RdKafka::ERR__QUEUE_FULL) {
           producer->poll(100);
           continue;
         } else if (resp != RdKafka::ERR_NO_ERROR) {
-          errorString("producer_send_error",
-                      RdKafka::err2str(resp), topic->name(), NULL, msg.str());
+          errorString("producer_send_error", RdKafka::err2str(resp),
+                      topic->name(), NULL, msg.str());
           state.producer.numErr++;
         } else {
           state.producer.numSent++;
@@ -868,15 +869,16 @@ int main (int argc, char **argv) {
     run = 1;
 
     while (run && producer->outq_len() > 0) {
-      std::cerr << now() << ": Waiting for " << producer->outq_len() << std::endl;
+      std::cerr << now() << ": Waiting for " << producer->outq_len()
+                << std::endl;
       producer->poll(1000);
       watchdog_kick();
     }
 
-    std::cerr << now() << ": " << state.producer.numAcked << "/" <<
-        state.producer.numSent << "/" << state.maxMessages <<
-        " msgs acked/sent/max, " << state.producer.numErr <<
-        " errored" << std::endl;
+    std::cerr << now() << ": " << state.producer.numAcked << "/"
+              << state.producer.numSent << "/" << state.maxMessages
+              << " msgs acked/sent/max, " << state.producer.numErr << " errored"
+              << std::endl;
 
     delete topic;
     delete producer;
@@ -900,21 +902,21 @@ int main (int argc, char **argv) {
      */
     consumer = RdKafka::KafkaConsumer::create(conf, errstr);
     if (!consumer) {
-      std::cerr << now() << ": Failed to create consumer: " <<
-          errstr << std::endl;
+      std::cerr << now() << ": Failed to create consumer: " << errstr
+                << std::endl;
       exit(1);
     }
 
-    std::cerr << now() << ": % Created consumer " << consumer->name() <<
-        std::endl;
+    std::cerr << now() << ": % Created consumer " << consumer->name()
+              << std::endl;
 
     /*
      * Subscribe to topic(s)
      */
     RdKafka::ErrorCode resp = consumer->subscribe(topics);
     if (resp != RdKafka::ERR_NO_ERROR) {
-      std::cerr << now() << ": Failed to subscribe to " << topics.size() << " topics: "
-                << RdKafka::err2str(resp) << std::endl;
+      std::cerr << now() << ": Failed to subscribe to " << topics.size()
+                << " topics: " << RdKafka::err2str(resp) << std::endl;
       exit(1);
     }
 
