@@ -1,7 +1,7 @@
 /*
  * librdkafka - Apache Kafka C library
  *
- * Copyright (c) 2018 Magnus Edenhill
+ * Copyright (c) 2018-2022, Magnus Edenhill
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -76,7 +76,7 @@ extern "C" {
 typedef uint32_t rd_crc32_t;
 
 #if !WITH_ZLIB
-extern 	const rd_crc32_t crc_table[256];
+extern const rd_crc32_t crc_table[256];
 #endif
 
 
@@ -95,12 +95,11 @@ rd_crc32_t rd_crc32_reflect(rd_crc32_t data, size_t data_len);
  *
  * \return     The initial crc value.
  *****************************************************************************/
-static RD_INLINE rd_crc32_t rd_crc32_init(void)
-{
+static RD_INLINE rd_crc32_t rd_crc32_init(void) {
 #if WITH_ZLIB
         return crc32(0, NULL, 0);
 #else
-    return 0xffffffff;
+        return 0xffffffff;
 #endif
 }
 
@@ -113,7 +112,7 @@ static RD_INLINE rd_crc32_t rd_crc32_init(void)
  * \param data_len Number of bytes in the \a data buffer.
  * \return         The updated crc value.
  *****************************************************************************/
-	/**
+/**
  * Update the crc value with new data.
  *
  * \param crc      The current crc value.
@@ -121,22 +120,22 @@ static RD_INLINE rd_crc32_t rd_crc32_init(void)
  * \param data_len Number of bytes in the \a data buffer.
  * \return         The updated crc value.
  *****************************************************************************/
-static RD_INLINE RD_UNUSED
-rd_crc32_t rd_crc32_update(rd_crc32_t crc, const unsigned char *data, size_t data_len)
-{
+static RD_INLINE RD_UNUSED rd_crc32_t rd_crc32_update(rd_crc32_t crc,
+                                                      const unsigned char *data,
+                                                      size_t data_len) {
 #if WITH_ZLIB
         rd_assert(data_len <= UINT_MAX);
-        return crc32(crc, data, (uInt) data_len);
+        return crc32(crc, data, (uInt)data_len);
 #else
-    unsigned int tbl_idx;
+        unsigned int tbl_idx;
 
-    while (data_len--) {
-        tbl_idx = (crc ^ *data) & 0xff;
-        crc = (crc_table[tbl_idx] ^ (crc >> 8)) & 0xffffffff;
+        while (data_len--) {
+                tbl_idx = (crc ^ *data) & 0xff;
+                crc     = (crc_table[tbl_idx] ^ (crc >> 8)) & 0xffffffff;
 
-        data++;
-    }
-    return crc & 0xffffffff;
+                data++;
+        }
+        return crc & 0xffffffff;
 #endif
 }
 
@@ -147,12 +146,11 @@ rd_crc32_t rd_crc32_update(rd_crc32_t crc, const unsigned char *data, size_t dat
  * \param crc  The current crc value.
  * \return     The final crc value.
  *****************************************************************************/
-static RD_INLINE rd_crc32_t rd_crc32_finalize(rd_crc32_t crc)
-{
+static RD_INLINE rd_crc32_t rd_crc32_finalize(rd_crc32_t crc) {
 #if WITH_ZLIB
         return crc;
 #else
-    return crc ^ 0xffffffff;
+        return crc ^ 0xffffffff;
 #endif
 }
 
@@ -160,14 +158,13 @@ static RD_INLINE rd_crc32_t rd_crc32_finalize(rd_crc32_t crc)
 /**
  * Wrapper for performing CRC32 on the provided buffer.
  */
-static RD_INLINE rd_crc32_t rd_crc32 (const char *data, size_t data_len) {
-	return rd_crc32_finalize(rd_crc32_update(rd_crc32_init(),
-						 (const unsigned char *)data,
-						 data_len));
+static RD_INLINE rd_crc32_t rd_crc32(const char *data, size_t data_len) {
+        return rd_crc32_finalize(rd_crc32_update(
+            rd_crc32_init(), (const unsigned char *)data, data_len));
 }
 
 #ifdef __cplusplus
-}           /* closing brace for extern "C" */
+} /* closing brace for extern "C" */
 #endif
 
-#endif      /* __RDCRC32___H__ */
+#endif /* __RDCRC32___H__ */
