@@ -101,7 +101,7 @@ static void await_assignment(const char *pfx,
         if (fails > 0)
                 TEST_FAIL("%s: assignment mismatch: see above", pfx);
 
-        rd_kafka_assign(rk, tps);
+        test_consumer_assign_by_rebalance_protocol("rebalance event", rk, tps);
         rd_kafka_event_destroy(rkev);
 }
 
@@ -112,6 +112,7 @@ static void await_assignment(const char *pfx,
 static void
 await_revoke(const char *pfx, rd_kafka_t *rk, rd_kafka_queue_t *queue) {
         rd_kafka_event_t *rkev;
+        rd_kafka_topic_partition_list_t *tps;
 
         TEST_SAY("%s: waiting for revoke\n", pfx);
         rkev = test_wait_event(queue, RD_KAFKA_EVENT_REBALANCE, 30000);
@@ -121,7 +122,10 @@ await_revoke(const char *pfx, rd_kafka_t *rk, rd_kafka_queue_t *queue) {
                         RD_KAFKA_RESP_ERR__REVOKE_PARTITIONS,
                     "expected REVOKE, got %s",
                     rd_kafka_err2str(rd_kafka_event_error(rkev)));
-        rd_kafka_assign(rk, NULL);
+        tps = rd_kafka_event_topic_partition_list(rkev);
+
+        test_consumer_unassign_by_rebalance_protocol("rebalance event", rk,
+                                                     tps);
         rd_kafka_event_destroy(rkev);
 }
 
@@ -266,6 +270,7 @@ static void do_test_regex(void) {
         rd_kafka_t *rk;
         rd_kafka_conf_t *conf;
         rd_kafka_queue_t *queue;
+        const char *rebalance_protocol;
 
         /**
          * Regex test:
@@ -308,10 +313,18 @@ static void do_test_regex(void) {
         TEST_SAY("Regex: creating topic %s (subscribed)\n", topic_d);
         test_create_topic_wait_exists(NULL, topic_d, 1, 1, 5000);
 
-        await_revoke("Regex: rebalance after topic creation", rk, queue);
+        if (test_consumer_group_protocol_classic())
+                await_revoke("Regex: rebalance after topic creation", rk,
+                             queue);
 
-        await_assignment("Regex: two topics exist", rk, queue, 2, topic_b, 2,
-                         topic_d, 1);
+        rebalance_protocol = rd_kafka_rebalance_protocol(rk);
+        if (!strcmp(rebalance_protocol, "COOPERATIVE")) {
+                await_assignment("Regex: two topics exist", rk, queue, 1,
+                                 topic_d, 1);
+        } else {
+                await_assignment("Regex: two topics exist", rk, queue, 2,
+                                 topic_b, 2, topic_d, 1);
+        }
 
         test_consumer_close(rk);
         rd_kafka_queue_destroy(queue);
@@ -674,17 +687,143 @@ static void do_test_replica_rack_change_leader_no_rack_mock(
         SUB_TEST_PASS();
 }
 
+/**
+ * Checking assignments and revocation operations for subscribe and
+ * unsubcribe with regular topic names and regex.
+ */
+static void do_test_resubscribe_with_regex() {
+        char *topic1  = rd_strdup(test_mk_topic_name("topic_regex1", 1));
+        char *topic2  = rd_strdup(test_mk_topic_name("topic_regex2", 1));
+        char *topic_a = rd_strdup(test_mk_topic_name("topic_a", 1));
+        char *group   = rd_strdup(
+            tsprintf("group_test_sub_regex_%s", test_str_id_generate_tmp()));
+        rd_kafka_t *rk;
+        rd_kafka_conf_t *conf;
+        rd_kafka_queue_t *queue;
+
+        SUB_TEST("Resubscribe with Regex");
+
+        /**
+         * Topic resubscribe with regex test:
+         * - Create topic topic_regex1 & topic_regex2
+         * - Subscribe to topic_regex1
+         * - Verify topic_regex1 assignment
+         * - Unsubscribe
+         * - Verify revocation
+         * - Subscribe to topic_regex2
+         * - Verify topic_regex2 assignment
+         * - Unsubscribe
+         * - Verify revocation
+         * - Subscribe to regex ^.*topic_regex.*
+         * - Verify topic_regex1 & topic_regex2 assignment
+         * - Unsubscribe
+         * - Verify revocation
+         * - Subscribe to regex ^.*topic_regex.* and topic_a
+         * - Verify topic_regex1, topic_regex2 and topic_a assignment
+         * - Unsubscribe
+         * - Verify revocation
+         */
+
+        TEST_SAY("Creating topic %s\n", topic1);
+        test_create_topic_wait_exists(NULL, topic1, 4, 1, 5000);
+
+        TEST_SAY("Creating topic %s\n", topic2);
+        test_create_topic_wait_exists(NULL, topic2, 4, 1, 5000);
+
+        TEST_SAY("Creating topic %s\n", topic_a);
+        test_create_topic_wait_exists(NULL, topic_a, 2, 1, 5000);
+
+        test_conf_init(&conf, NULL, 60);
+
+        rd_kafka_conf_set_events(conf, RD_KAFKA_EVENT_REBALANCE);
+        rk    = test_create_consumer(group, NULL, conf, NULL);
+        queue = rd_kafka_queue_get_consumer(rk);
+
+        /* Subscribe to topic1 */
+        TEST_SAY("Subscribing to %s\n", topic1);
+        test_consumer_subscribe(rk, topic1);
+        /* Wait for assignment */
+        await_assignment("Assignment for topic1", rk, queue, 1, topic1, 4);
+
+        /* Unsubscribe from topic1 */
+        TEST_SAY("Unsubscribing from %s\n", topic1);
+        rd_kafka_unsubscribe(rk);
+        /* Wait for revocation */
+        await_revoke("Revocation after unsubscribing", rk, queue);
+
+        /* Subscribe to topic2 */
+        TEST_SAY("Subscribing to %s\n", topic2);
+        test_consumer_subscribe(rk, topic2);
+        /* Wait for assignment */
+        await_assignment("Assignment for topic2", rk, queue, 1, topic2, 4);
+
+        /* Unsubscribe from topic2 */
+        TEST_SAY("Unsubscribing from %s\n", topic2);
+        rd_kafka_unsubscribe(rk);
+        /* Wait for revocation */
+        await_revoke("Revocation after unsubscribing", rk, queue);
+
+        /* Subscribe to regex ^.*topic_regex.* */
+        TEST_SAY("Subscribing to regex ^.*topic_regex.*\n");
+        test_consumer_subscribe(rk, "^.*topic_regex.*");
+        if (!test_consumer_group_protocol_classic()) {
+                /** Regex matching is async on the broker side for KIP-848
+                 * protocol. */
+                rd_sleep(5);
+        }
+        /* Wait for assignment */
+        await_assignment("Assignment for topic1 and topic2", rk, queue, 2,
+                         topic1, 4, topic2, 4);
+
+        /* Unsubscribe from regex ^.*topic_regex.* */
+        TEST_SAY("Unsubscribing from regex ^.*topic_regex.*\n");
+        rd_kafka_unsubscribe(rk);
+        /* Wait for revocation */
+        await_revoke("Revocation after unsubscribing", rk, queue);
+
+        /* Subscribe to regex ^.*topic_regex.* and topic_a literal */
+        TEST_SAY("Subscribing to regex ^.*topic_regex.* and topic_a\n");
+        test_consumer_subscribe_multi(rk, 2, "^.*topic_regex.*", topic_a);
+        /* Wait for assignment */
+        if (test_consumer_group_protocol_classic()) {
+                await_assignment("Assignment for topic1, topic2 and topic_a",
+                                 rk, queue, 3, topic1, 4, topic2, 4, topic_a,
+                                 2);
+        } else {
+                /* KIP-848 broker is assigning literal topics first in 1 HB call
+                 * and all the matched ones in later HB call*/
+                await_assignment("Assignment for topic_a", rk, queue, 1,
+                                 topic_a, 2);
+                await_assignment("Assignment for topic1 and topic2", rk, queue,
+                                 2, topic1, 4, topic2, 4);
+        }
+
+        /* Unsubscribe */
+        TEST_SAY("Unsubscribing\n");
+        rd_kafka_unsubscribe(rk);
+        await_revoke("Revocation after unsubscribing", rk, queue);
+
+        /* Cleanup */
+        test_delete_topic(rk, topic1);
+        test_delete_topic(rk, topic2);
+
+        test_consumer_close(rk);
+        rd_kafka_queue_destroy(queue);
+
+        rd_kafka_destroy(rk);
+
+        rd_free(topic1);
+        rd_free(topic2);
+        rd_free(group);
+
+        SUB_TEST_PASS();
+}
+
 int main_0045_subscribe_update(int argc, char **argv) {
 
         if (!test_can_create_topics(1))
                 return 0;
 
-        /* TODO: check again when regexes will be supported by KIP-848 */
-        if (!test_consumer_group_protocol_classic()) {
-                TEST_SKIP("Still not supported by KIP-848\n");
-                return 0;
-        }
-
         do_test_regex();
 
         return 0;
@@ -711,12 +850,6 @@ int main_0045_subscribe_update_topic_remove(int argc, char **argv) {
 int main_0045_subscribe_update_mock(int argc, char **argv) {
         TEST_SKIP_MOCK_CLUSTER(0);
 
-        /* TODO: check again when regexes will be supported by KIP-848 */
-        if (!test_consumer_group_protocol_classic()) {
-                TEST_SKIP("Still not supported by KIP-848\n");
-                return 0;
-        }
-
         do_test_regex_many_mock("range", rd_false);
         do_test_regex_many_mock("cooperative-sticky", rd_false);
         do_test_regex_many_mock("cooperative-sticky", rd_true);
@@ -724,6 +857,10 @@ int main_0045_subscribe_update_mock(int argc, char **argv) {
         return 0;
 }
 
+int main_0045_resubscribe_with_regex(int argc, char **argv) {
+        do_test_resubscribe_with_regex();
+        return 0;
+}
 
 int main_0045_subscribe_update_racks_mock(int argc, char **argv) {
         int use_replica_rack = 0;
